# Changelog

## 0.1.0 (2025-12-08)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/CaseMark/casedev-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([f016636](https://github.com/CaseMark/casedev-python/commit/f01663617b152a538b7ca668272be3dfcc3b0dc9))
* **api:** api update ([3966424](https://github.com/CaseMark/casedev-python/commit/3966424bf12ae7bd1c389fb18e85ec27fb784b4c))
* **api:** api update ([bdd8f5b](https://github.com/CaseMark/casedev-python/commit/bdd8f5b481346d6354609b4b09ebae8dbd71a9fc))
* **api:** api update ([8d0cbe9](https://github.com/CaseMark/casedev-python/commit/8d0cbe93ef8fb68e4895b064c7a5483b8d50dc2c))
* **api:** api update ([46a5bca](https://github.com/CaseMark/casedev-python/commit/46a5bcab1b018f33c1c45daf3584678fece36f3c))
* **api:** manual updates ([0857a27](https://github.com/CaseMark/casedev-python/commit/0857a27df9330ed223236f22b4c086146c15d1f8))
* **api:** manual updates ([eeb7830](https://github.com/CaseMark/casedev-python/commit/eeb7830cb058b1ef4be3c6edfefa1a33efe16f0e))
* **api:** manual updates ([7c7022f](https://github.com/CaseMark/casedev-python/commit/7c7022f6e7b5603b8e98f75fe102219f789ff3ba))


### Bug Fixes

* ensure streams are always closed ([b30b9ec](https://github.com/CaseMark/casedev-python/commit/b30b9ec808299da7d4bfade2a52b9a5529bf3d9a))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([714ab77](https://github.com/CaseMark/casedev-python/commit/714ab7768f8895da8e0e6c56ceb506dd946d7e76))
* **docs:** use environment variables for authentication in code snippets ([f57c037](https://github.com/CaseMark/casedev-python/commit/f57c037c435e38d740180acdfa155252f610315e))
* update lockfile ([56cba77](https://github.com/CaseMark/casedev-python/commit/56cba77d5c25b33a5464120c58e648a44921b43c))
* update SDK settings ([0fb22b3](https://github.com/CaseMark/casedev-python/commit/0fb22b30b2bf11f50b8c7a23e020c3e51878f817))
